"""
递归函数打印多维数组
"""
def print_names (names, level=0) :
    for each_name in names :
        if isinstance(each_name, list):
            print_names(each_name, level+1)
        else:
            for tab_stop in range(level):
                print("\t", end='')
            print(each_name)



from distutils.core import setup

setup(
    name        =   'dgzi-nester',
    version     =   '1.0.3',
    py_modules  =   ['nester'],
    author      =   'guangzhao.di',
    author_email=   '1280029266@qq.com',
    url         =   'http://dgz66.com',
    description =   'A simple distutils test',
    )
